$(document).ready(function () {
  mapboxgl.accessToken = jQuery("#hdnMapAPI").val();
  mapboxgl.setRTLTextPlugin(
    "https://api.mapbox.com/mapbox-gl-js/plugins/mapbox-gl-rtl-text/v0.2.3/mapbox-gl-rtl-text.js"
  );
  if ($(window).width() > 768) {
    var map = new mapboxgl.Map({
      container: "map",
      style: "mapbox://styles/mapbox/light-v11",
      center: [-85.4403293, 35.4440176],
      zoom: 3,
      scrollZoom: true,
    });
  } else {
    var map = new mapboxgl.Map({
      container: "map",
      style: "mapbox://styles/mapbox/light-v11",
      center: [-85.4403293, 35.4440176],
      zoom: 2,
      scrollZoom: true,
    });
  }

  var geojson = {
    type: "FeatureCollection",
    features: [
      {
        type: "Feature",
        geometry: {
          type: "Point",
          coordinates: [-90.16129678619562, 46.47297220147939],
        },
        properties: {
          image: "assets/locations/iron-wood.png",
          description: "824 E Cloverland Dr, Ironwood, MI 49938, United States",
        },
      },
      {
        type: "Feature",
        geometry: {
          type: "Point",
          coordinates: [-88.33476222026637, 46.098212494949934],
        },
        properties: {
          image: "assets/locations/iron-wood.png",
          description:
            "116 Superior Ave, Crystal Falls, MI 49920, United States",
        },
      },
      {
        type: "Feature",
        geometry: {
          type: "Point",
          coordinates: [-85.56173554430742, 42.230223252440844],
        },
        properties: {
          image: "assets/locations/buds-marys.png",
          description: "2401 E Milham Ave, Portage, MI 49002, United States",
        },
      },
      {
        type: "Feature",
        geometry: {
          type: "Point",
          coordinates: [-86.36044338157348, 41.82858936955025],
        },
        properties: {
          image: "assets/locations/cannavista.png",
          description: "120 E Front St, Buchanan, MI 49107, United States",
        },
      },
      {
        type: "Feature",
        geometry: {
          type: "Point",
          coordinates: [-85.6848180023893, 42.98529969339148],
        },
        properties: {
          image: "assets/locations/nature-releaf.png",
          description:
            "666 Leonard St NW, Grand Rapids, MI 49504, United States",
        },
      },
      {
        type: "Feature",
        geometry: {
          type: "Point",
          coordinates: [-86.71066206145602, 45.900702576589374],
        },
        properties: {
          image: "assets/locations/wacky-jackz.png",
          description: "12840 U.S. Rte 2, Rapid River, MI 49878, United States",
        },
      },
      {
        type: "Feature",
        geometry: {
          type: "Point",
          coordinates: [-83.66803410601032, 43.044785718185096],
        },
        properties: {
          image: "assets/locations/sweat-leaf.png",
          description: "400 S Dort Hwy, Flint, MI 48503, United States",
        },
      },
      {
        type: "Feature",
        geometry: {
          type: "Point",
          coordinates: [-85.18697492155096, 44.73872162765127],
        },
        properties: {
          image: "assets/locations/green-pharm.png",
          description: "764 S Cedar St, Kalkaska, MI 49646, United States",
        },
      },
      {
        type: "Feature",
        geometry: {
          type: "Point",
          coordinates: [-85.6657554583321, 42.95996479703585],
        },
        properties: {
          image: "assets/locations/fluresh.png",
          description:
            "1213 Phillips Ave SW, Grand Rapids, MI 49507, United States",
        },
      },
      {
        type: "Feature",
        geometry: {
          type: "Point",
          coordinates: [-83.02941353900592, 42.49097002410607],
        },
        properties: {
          image: "assets/locations/joyology.png",
          description: "26550 Liberal St, Center Line, MI 48015, United States",
        },
      },
      {
        type: "Feature",
        geometry: {
          type: "Point",
          coordinates: [-83.10058737632671, 42.47209557006075],
        },
        properties: {
          image: "assets/locations/breeze.png",
          description: "24517 John R Rd, Hazel Park, MI 48030, United States",
        },
      },
      {
        type: "Feature",
        geometry: {
          type: "Point",
          coordinates: [-83.46614730005778, 42.539504319433],
        },
        properties: {
          image: "assets/locations/bazonzoes.png",
          description: "1760 E West Maple Rd, Walled Lake, MI 48390, United States",
        },
      },
      {
        type: "Feature",
        geometry: {
          type: "Point",
          coordinates: [-83.12642705234869, 42.46712370042819],
        },
        properties: {
          image: "assets/locations/remedy.png",
          description: "925 E Drayton St Ferndale, Mi 48220",
        },
      },
    ],
  };

  geojson.features.forEach(function (marker) {
    var el = document.createElement("div");
    el.className = "mapbg-icon";
    new mapboxgl.Marker(el)
      .setLngLat(marker.geometry.coordinates)
      .setPopup(
        new mapboxgl.Popup({ offset: 25 }) // add popups
          .setHTML(
            `<img src='${marker.properties.image}' class='w-100 mb-2' />` +
              "<p class='mb-2'>" +
              marker.properties.description +
              "</p>"
          )
      )
      .addTo(map);
  });

  map.addControl(new mapboxgl.NavigationControl());

  var geocoder = new MapboxGeocoder({
    accessToken: mapboxgl.accessToken,
    types: "country,region,place,postcode",
    marker: true,
    mapboxgl: mapboxgl,
  });

  document.getElementById("map-search-form").appendChild(geocoder.onAdd(map));

  geocoder.on("result", function (e) {
    map.setCenter(e.result.center);
  });

  // Attach a click event listener to all links with class "place"
  $(".place").click(function (e) {
    e.preventDefault();
    var coord = $(this).data("coord").split(",");
    var lngLat = { lng: parseFloat(coord[0]), lat: parseFloat(coord[1]) };
    map.flyTo({
      center: lngLat,
      zoom: 15,
    });
  });
});
